@@ -4,6 +4,7 @@
 #http://wap.jue-huo.com/app/html/game/1to50/1to50.html
 
 import sys,dlib,numpy
+
 #pip install scikit-image
 from skimage import io
 import cv2
@@ -16,7 +17,23 @@ from os.path import dirname
 import requests
 import bz2#bz2file pypi
 import zipfile
-
+def loadDBFromFeatureFiles(folder):
+    files = os.listdir(folder)
+    with open(folder+"\\" + "IDs.txt",encoding='utf8') as ff:
+        IDs = ff.readlines()
+    for ID in IDs:
+        print("load "+ ID.strip() +".npy")
+        DB[ID.strip()]=numpy.load(folder+"\\"+ID.strip()+'.npy')
+            
+            
+def saveDB(folder):
+    _createFolder(folder)
+    for key in DB.keys():
+        numpy.save(folder+"\\"+key.strip(),DB[key.strip()])
+    with open(folder+'\\'+'IDs.txt','w',encoding='utf8') as fkey:        
+        for key in DB.keys():
+            fkey.write(key.strip()+"\n")        
+        
 def download_file_from_google_drive(id, destination):
     URL = "https://docs.google.com/uc?export=download"
     session = requests.Session()
@@ -319,7 +336,7 @@ def predictCam(camSerial=None,skipFranmes=1,outputFileName="",db=DB):
                     frame=addText2Img_cv2(frame,Tag+":"+str(round(dist,3)),_FONT,(rect.left(), rect.top()-_FONT.size-1))        
                     if outputFileName!="":
                         try:
-                            with open(outputFileName,'w') as f:
+                            with open(outputFileName,'w',encoding='UTF-8') as f:
                                 f.write(Tag+'\t'+str(dist))
                         except:print("file exception...")
             except IndexError:pass    
@@ -376,10 +393,11 @@ if __name__ == "__main__":
     loadDB(folder='train')
     result = predictFromDB(VTest)
     print(result)
-    
-    #vedio Demo
-    loadDB(folder='train')
-    predictCam()
     '''
-    
-    
\ No newline at end of file
+    #vedio Demo
+    #loadDB(folder='train')
+    #
+    #saveDB('features')
+    #loadDBFromFeatureFiles("features")
+    #print(DB['四葉草'])
+    #predictCam()
\ No newline at end of file
